@@ -7,7 +7,7 @@
     legend.mar = ifelse(horizontal, 3.1, 5.1), legend.lab = NULL, 
     graphics.reset = FALSE, bigplot = NULL, smallplot = NULL, 
     legend.only = FALSE, col = tim.colors(nlevel), lab.breaks = NULL, 
-    axis.args = NULL, legend.args = NULL, midpoint = FALSE, border=NA, lwd.poly=1.0) {
+    axis.args = NULL, legend.args = NULL, midpoint = FALSE, border=NA, lwd=1.0) {
     # Thanks to S. Koehler and  S. Woodhead
     # for comments on making this a better function
     #
@@ -25,14 +25,14 @@
         legend.mar <- ifelse(horizontal, 3.1, 5.1)
     }
     #
-    # figure out how to divide up the plotting real estate.
+    # figure out how to divide up the plotting real estate this
     #
     temp <- image.plot.plt(add = add, legend.shrink = legend.shrink, 
         legend.width = legend.width, legend.mar = legend.mar, 
         horizontal = horizontal, bigplot = bigplot, smallplot = smallplot)
     #
-    # bigplot are plotting region coordinates for image
-    # smallplot are plotting coordinates for legend
+    # bigplot has plotting region coordinates for image
+    # smallplot has plotting coordinates for legend
     smallplot <- temp$smallplot
     bigplot <- temp$bigplot
     #
@@ -48,7 +48,7 @@
         }
         else {
             poly.image(..., add = add, col = col, midpoint = midpoint,
-                            border=border, lwd.poly=lwd.poly)
+                            border=border, lwd.poly=lwd)
         }
         big.par <- par(no.readonly = TRUE)
     }
